/*
 * Part of CollapsiblePanel Widget
 *
 * Created: 2017-12-26
 * Qt Creator 4.4.1 Based on Qt 5.9.2
 *  Author: Krzysztof Markiewicz
 *  www.obbo.pl
 *
 * This program is distributed under the terms of the GNU General Public License
 */

#include <QtWidgets>
#include "collapsiblepanel.h"


CollapsiblePanel::CollapsiblePanel(QWidget *parent) :
    QWidget(parent)
{
    this->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
    toggleButton = new QToolButton(this);
    toggleButton->setObjectName(QStringLiteral("__qt__passive_toggleButton"));
    toggleButton->setStyleSheet("QToolButton {border: none; background-color: rgba(255, 255, 255, 0);}");
    setCollapsiblePanelIcon(QIcon());
    toggleButton->setCheckable(true);
    toggleButton->setChecked(false);
    toggleButton->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
    toggleButton->setAttribute(Qt::WA_TranslucentBackground);
    toggleButton->setContentsMargins(0, 0, 0, 0);
    // set StyleSheet {padding-right: 0px;} to non shift icon on toggleButton
    // alternatively have to use QProxyStyle
    checkBox = new QCheckBox(this);
    checkBox->setObjectName(QStringLiteral("__qt__passive_comboBox"));
    checkBox->setText("");
    checkBox->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
    checkBox->setAttribute(Qt::WA_TranslucentBackground);
    checkBox->setLayoutDirection(Qt::RightToLeft);
    checkBox->setStyleSheet("QCheckBox {border: none; background-color: rgba(255, 255, 255, 0);}");
    label = new QLabel(this);
    label->setObjectName(QStringLiteral("__qt__passive_label"));
    label->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
    label->setAttribute(Qt::WA_TranslucentBackground);
    label->setLineWidth(0);
    info = new QLabel(this);
    info->setObjectName(QStringLiteral("__qt__passive_text"));
    info->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
    info->setAttribute(Qt::WA_TranslucentBackground);
    info->setLineWidth(0);
    setTextVisible();
    spacer = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Fixed);
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);
    layout->addWidget(toggleButton, 0, Qt::AlignLeft);
    layout->addWidget(checkBox, 0, Qt::AlignLeft);
    layout->addWidget(label, 0, Qt::AlignLeft);
    layout->addSpacerItem(spacer);
    layout->addWidget(info, 0, Qt::AlignLeft);
    setLayout(layout);
    connect(checkBox, &QCheckBox::clicked, this, &CollapsiblePanel::setChecked);
    connect(toggleButton, &QToolButton::clicked, this, &CollapsiblePanel::toggleButtonChanged);
}

void CollapsiblePanel::setCollapsiblePanelIcon(QIcon icon)
{
    if (icon.isNull())
        setCollapsiblePanelArrow(isCollapsed());
    else
        toggleButton->setArrowType(Qt::NoArrow);
    toggleButton->setIcon(icon);
}

void CollapsiblePanel::setCollapsiblePanelArrow(bool collapsed)
{
    toggleButton->setArrowType(collapsed ? Qt::DownArrow : Qt::UpArrow);
}

void CollapsiblePanel::paintEvent(QPaintEvent *)
{
    QStyleOption opt;
    opt.init(this);
    QPainter p(this);
    style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
}

void CollapsiblePanel::setIcon(QIcon icon)
{
    setCollapsiblePanelIcon(icon);
}

QIcon CollapsiblePanel::icon()
{
    return toggleButton->icon();
}

void CollapsiblePanel::setTitle(QString text)
{
    label->setText(text);
}

QString CollapsiblePanel::title()
{
    return label->text();
}

bool CollapsiblePanel::isCheckable()
{
    return checkBox->isCheckable();
}

void CollapsiblePanel::setCheckable(bool checked)
{
    checkBox->setCheckable(checked);
    checkBox->setVisible(checked);
}

bool CollapsiblePanel::isChecked()
{
    return checkBox->isChecked();
}

void CollapsiblePanel::setChecked(bool checked)
{
    checkBox->setChecked(checked);
    emit checkedChanged(checked);
}

QSize CollapsiblePanel::iconSize()
{
    return toggleButton->iconSize();
}

void CollapsiblePanel::setIconSize(QSize size)
{
    toggleButton->setIconSize(size);
}

bool CollapsiblePanel::isCollapsed()
{
    return !(toggleButton->isChecked());
}

void CollapsiblePanel::toggleButtonChanged()
{
    setCollapsed(isCollapsed());
}

void CollapsiblePanel::setCollapsed(bool collapsed)
{
    toggleButton->setChecked(!collapsed);
    setCollapsiblePanelIcon(icon());
    emit collapsedChanged(collapsed);
}

void CollapsiblePanel::update()
{
    setCollapsed(isCollapsed());
}

QString CollapsiblePanel::text()
{
    return info->text();
}

void CollapsiblePanel::setText(QString text)
{
    info->setText(text);
}

void CollapsiblePanel::setTextVisible(bool visible)
{
    textVisible = visible;
    info->setVisible(textVisible);
}

