/*
 * Part of BarGraph widget
 *
 * Created: 2018-11-22
 * Qt Creator 4.4.1 Based on Qt 5.9.2
 *  Author: Krzysztof Markiewicz
 *  www.obbo.pl
 *
 * This program is distributed under the terms of the GNU General Public License
 */

#ifndef BARGRAPH_H
#define BARGRAPH_H

#include <QWidget>
#include <QLabel>


class BarGraph : public QWidget
{
    Q_OBJECT

public:
    explicit BarGraph(QWidget *parent = nullptr);
    QSize sizeHint() const override;
    QSize minimumSizeHint() const;
    void setMinorTick(int length);
    void setMajorTick(int length);
    void setTickWidth(int width);
    void setMajorTickRising(bool rising);
    void setBarColor(QColor color);
    void setBackgroundColor(QColor color);
    void setRange(double min, double max);
    void setValue(double value);
    void setAlarmVisible(bool visible);
    void setAlarmColors(QColor warning, QColor critical);
    void setAlarm(double bCritical, double bWarning, double tWarining, double tCritical);

protected:
    virtual void resizeEvent(QResizeEvent *);

private:
    QLabel *labelAxis;
    QLabel *labelBarL;
    QLabel *labelBarR;
    const int TICK_SPACE = 1;
    const QString BAR_TRANSPARENCY = "dc";
    typedef struct {
        int minorTick;
        int majorTick;
        int tickWidth;
        QColor tickColor;
        QColor barColor;
        bool majorTickRising;
    } Axis;
    Axis axis;
    typedef struct {
        double minimum;
        double maximum;
        double value;
    } Bar;
    Bar bar;
    typedef struct {
        QColor critical;
        QColor warning;
        double topCritical;
        double topWarning;
        double bottomWarning;
        double bottomCritical;
        bool visible;
    } Alarm;
    Alarm alarm;
    QString addTransparency(QString color);
    int getBarWidth(Axis ax) const;
    int getTickStep(int width, Axis ax);
    int getOffset(int width, Axis ax);
    int getAxisWidth(int ticks, Axis ax) const;
    void drawTick(QPainter *p, int x, int length, Axis ax, int offset);
    void drawAxis(Axis ax, int width);
    void drawAxis();
    void drawBar(int width, Axis ax, Bar bar);
    void drawBar();

};

#endif // BARGRAPH_H

