#ifndef LIBUSBDEVICE_H
#define LIBUSBDEVICE_H
#include <QObject>
#include <QFuture>
#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
#include <QtConcurrent/QtConcurrent>
#else
#include <QtConcurrentRun>
#endif
#include "libusb.h"
#include "libusbdeviceinfo.h"
#include <QDebug>
#include "serialportconnection.h"


typedef uint8_t byte;

class LibUsbDevice : public QObject
{
    Q_OBJECT
public:
    explicit LibUsbDevice(QObject* parent = 0);
    void initializeDevice();
    void openDevice();
    void closeDevice();
    void eventThread();
    int controlReadTransfer(uint8_t command, unsigned char* buffer, int length, uint16_t index = 0, uint16_t value = 0);
    void asyncBulkReadTransfer();
    void bulkWriteTransfer(unsigned char* buffer, int length);
    void controlWriteTransfer(uint8_t command, uint16_t index = 0, uint16_t value = 0);
    void reset();    

private:
    void libUsbTransferResultError(int errCode);
    bool checkIsDeviceConnected();
    QTimer timerKeepAlive;

public slots:
    void newDataAvailable(int);
    void clearData();

public:
    bool isDeviceConnected;
    bool isInitialiazed;
    QString cstatus;
    libusb_device** devs;
    libusb_device* deviceFound;
    libusb_device* dev;
    libusb_device_descriptor deviceDesc;
    libusb_device_handle* deviceHandle;
    libusb_context* context;
    libusb_hotplug_callback_handle hotplugHandle[2];
    struct libusb_transfer* pcToUsbDeviceTransfer;
    struct libusb_transfer* usbDeviceToPcTransfer;
    bool dataAvailable;
    int count, dataLength;
    uint8_t chData[LEN_BULK_IN_BUFFER];
    bool enableEventThread,hasHotPlugSupport;
    QFuture<void> future;
    SerialPortConnection serial;
    bool usbConnectionLost;

signals:
    void connectionLost();
};

#endif // LIBUSBDEVICE_H
