/*
 * Part of Xlab Interface
 *
 * Created: 2017-12-16
 * Qt Creator 4.4.1 Based on Qt 5.9.2
 *  Author: Krzysztof Markiewicz
 *  www.obbo.pl
 *
 * This program is distributed under the terms of the GNU General Public License
 */

#ifndef PYTHONCONSOLE_H
#define PYTHONCONSOLE_H

#include <QApplication>
#include <QtWidgets>
#include <QShowEvent>
#include <QString>


class PythonQtScriptingConsole;
class PythonConsoleOptions;
class PythonXlabObject;
class PythonXlabObjectAWG;


class PythonConsole : public QMainWindow
{
	Q_OBJECT
public:
    PythonConsole(QWidget *parent, PythonConsoleOptions *options, bool *isRunning);
	~PythonConsole();

public slots:
    void evaluateScript(QString evalCode, bool notify = true);
    void runScript(QString fileName, bool notify = true);
    void applyConfiguration();

private:
    PythonConsoleOptions *configuration;
    bool *stateRunning;
    PythonQtScriptingConsole *pyConsole = nullptr;
    PythonXlabObject *pyObject = nullptr;
    PythonXlabObjectAWG *pyObjectAWG = nullptr;
    QFont currentFont;
    QTimer *resizeTimer;
    QLineEdit *lineEditWindowSize;
    QAction *actionOpenScript;
    QAction *actionClear;
    QAction *actionHide;
    QAction *actionSettings;
    QAction *actionClose;
    QMenu *mainMenu;
    void createMenu();
    int colsToPixel(int cols);
    int pixelToCols(int width);
    int rowsToPixel(int rows);
    int pixelToRows(int height);
    int countLines(QString evalCode);
    void initPythonConsole();
    void deletePythonConsole();
    void printConsole(QString string);
    void setFont(QString family, int size);

    const int RESIZE_TIMEOUT = 800;

signals:
    void configurationRequest(QString component);

private slots:
    void openScript();
    void clearConsole();
    void hideConsole();
    void closeConsole();
    void resizeTimeout();
    void callSettings();

protected:
    virtual void resizeEvent(QResizeEvent *event);

};

#endif // PYTHONCONSOLE_H
